macro_rules! svc {
($r0:expr) => { ... };
}Expand description
Generate an SVC call with the given argument.
Safe to call even in Supervisor (SupervisorCall) mode, as long as your Svc handler saves and restores SPSR_svc correctly.
macro_rules! svc {
($r0:expr) => { ... };
}Generate an SVC call with the given argument.
Safe to call even in Supervisor (SupervisorCall) mode, as long as your Svc handler saves and restores SPSR_svc correctly.