MemoryRegionAttributesRaw

Struct MemoryRegionAttributesRaw 

pub struct MemoryRegionAttributesRaw { /* private fields */ }
The ARM Cortex-A architecture reference manual p.1363 specifies these attributes in more detail.

The B (Bufferable), C (Cacheable), and TEX (Type extension) bit names are inherited from earlier versions of the architecture. These names no longer adequately describe the function of the B, C, and TEX bits.

Implementations

Source

impl MemoryRegionAttributesRaw

pub const fn new(type_extensions: u3, c: bool, b: bool) -> Self